## History

### Version 0.5.0 (2023-01-20)
- Modernize tooling
- Support python 3.9, 3.10, 3.11
- Support django 3.2, 4.1
- Update PrismJS to version 1.29.0
- Simplify DOM ready for modern browsers
- Update jsonsuit on toggle
- Support for multiple mixed forms

### Version 0.4.4 (2018-01-31)
- Update django doc links
- Remove unused load of i18n template tag
- Update prism assets

### Version 0.4.3 (2018-01-19)
- Fix toggling of JSON field instead of submitting
- Fix test for jsonsuit template tag
- Update test requirements
- Add renderer kwarg to the widget render fn
- Fix tox and travis config

### Version 0.4.2 (2017-07-03)
- Fix test for jsonsuit template tag
- Fix jsonsuit template tag for empty strings and add test case

### Version 0.4.1 (2017-06-19)
- Simplify tests to work with multiple python versions
- Fix docs about template tags

### Version 0.4.0 (2017-06-18)
- Add jsonsuit template tags

### Version 0.3.0 (2017-06-02)
- Add ReadonlyJSONSuit widget
- Make app settings more modular
- Make JS code more generic (mostly using classes in selectors)
- Use Prism's "default" theme as default

### Version 0.2.0 (2017-05-14)
- Change JSON syntax highlighter themes
- Set custom widget media (JS & CSS) files
- Use custom HTML template

### Version 0.1.0 (2017-05-13)
- First release on PyPI.
